:orphan: .. do not include this document into toctree

rebase-helper man page
======================

.. autoargs::
   :function: CLI.build_parser
   :module: rebasehelper.cli
   :program_name: rebase-helper
   :synopsis_max_width: 72
   :ignore_option_groups:

   DESCRIPTION : @replace
      .. include:: ../description.rst

   OPTION : -h : @replace
      show help message and exit

EXIT STATUS
-----------

This program returns 0 if successful, or non-zero if there was an error.

.. TODO: list of known issues
   NOTES
   -----

.. TODO: example of basic rebase
   EXAMPLE
   -------

SEE ALSO
--------

:manpage:`rpmbuild(8)`,
:manpage:`mock(1)`,
:manpage:`rpmdiff(1)`,
:manpage:`pkgdiff(1)`,
:manpage:`abipkgdiff(1)`,
:manpage:`csmock(1)`
